#!/usr/bin/env python
# -*- coding: utf-8 -*-

## Tivion
## Copyright (C) 2009 Ángel Guzmán Maeso
## http://shakaran.es
##
## This program is free software: you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys
import os
import constants as cons
import ConfigParser
import shutil

import locale
import gettext
cur_locale = locale.setlocale(locale.LC_ALL, '')
gettext.bindtextdomain('tivion', cons.LOCALE_DIR)
gettext.textdomain('tivion')
_ = gettext.gettext

def check_player():
    from os.path import exists as e
    return e("/usr/bin/mplayer") # and e("/usr/bin/serpentine")

def check_dir(path):
    if not os.path.exists(path):
        try:
            os.mkdir(path)
        except OSError:
            print _('Error, could not create dir \'%s\':' % path), e

    if not os.path.isdir(path):
        shutil.copy2(path, path + '_backup')
        os.remove(path)
        try:
            os.mkdir(path)
        except OSError:
            print _('Error, could not create dir \'%s\':' % path), e    

class Config():
    cfg = None
    path_cfg_dir = None
    path_cfg_file = None
    
    def __init__(self):
        self.cfg = ConfigParser.ConfigParser()
        self.path_cfg_dir = os.environ['HOME'] + '/.tivion'
        self.path_cfg_file = os.environ['HOME'] + '/.tivion/' + cons.CONFIG_FILE
        self.__check_cfg_dir()
        self.__check_cfg_file()
        self.__read_cfg_file()
        self.__check_sections(['OPTIONS'])
        self.__check_options('OPTIONS', [('Lang', cur_locale), # [FIXME] Dont use cur_locale
                                         ('Screenshot_folder', os.environ['HOME'] + '/.tivion/'+ _('captures'))])
        
    def __check_cfg_dir(self):
        check_dir(self.path_cfg_dir)

    def __check_cfg_file(self):
        if not os.path.exists(self.path_cfg_file):
            try:
                open(self.path_cfg_file, 'w')
            except IOError:
                print _('Error, could not create config file \'%s\':' % self.path_cfg_file), e
            
        if not os.path.isfile(self.path_cfg_file):
            shutil.copy2(self.path_cfg_dir, self.path_cfg_dir + '_backup')
            os.remove(self.path_cfg_file)
            try:
                open(self.path_cfg_file, 'w')
            except IOError:
                print _('Error, could not create config file \'%s\':' % self.path_cfg_file), e

    def __read_cfg_file(self):
        try:
            self.cfg.readfp(file(self.path_cfg_file))
        except Exception, e:
            print _('Error, could not read config file \'%s\':' % self.path_cfg_file), e
     
    def __write_cfg_file(self):
        with open(self.path_cfg_file, 'wb') as cfg_file:
            self.cfg.write(cfg_file)
    
    def write(self):
        self.__write_cfg_file()
            
    def __check_sections(self, sections):
        for s in sections:
            if not self.cfg.has_section(s):
                print _('Warning: section \'%s\' does not exists in conf file, created automatically.' % s)
                self.cfg.add_section(s)
                self.__write_cfg_file()

    def __check_options(self, section, options):
        for (op, default_value) in options:
            if not self.cfg.has_option(section, op):
                print _('Warning: section \'%s\' does not have the option ' %section) + _('\'%s\' in conf file, created automatically with default value' %op) +(' \'%s\'.' %default_value)
                self.cfg.set(section, op, default_value) 
                self.__write_cfg_file()
